@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef KADDRESSBOOKEXPORTSELECTIONWIDGET_H
 #define KADDRESSBOOKEXPORTSELECTIONWIDGET_H
 
-#include <QWidget>
 #include "kaddressbook_importexport_export.h"
+#include <QWidget>
 
 class QCheckBox;
-namespace KAddressBookImportExport {
+namespace KAddressBookImportExport
+{
 /** Addressbool export selection widget. */
 class KADDRESSBOOK_IMPORTEXPORT_EXPORT ExportSelectionWidget : public QWidget
 {
@@ -20,19 +21,12 @@ public:
     explicit ExportSelectionWidget(QWidget *parent = nullptr);
     ~ExportSelectionWidget() override;
 
-    enum ExportField {
-        None = 0,
-        Private = 1,
-        Business = 2,
-        Other = 4,
-        Encryption = 8,
-        Picture = 16,
-        DiplayName = 32
-    };
+    enum ExportField { None = 0, Private = 1, Business = 2, Other = 4, Encryption = 8, Picture = 16, DiplayName = 32 };
     Q_ENUM(ExportField)
     Q_DECLARE_FLAGS(ExportFields, ExportField)
 
     Q_REQUIRED_RESULT ExportFields exportType() const;
+
 private:
     void readSettings();
     void writeSettings();
